import subprocess
import sys

import pytest


@pytest.mark.calculates_crc32c
def test_benchmark() -> None:
    out = subprocess.check_output([sys.executable, "-m", "crc32c.benchmark"])
    assert b"crc32c ran at" in out



import os
import subprocess as sp
import sys

SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))


def run(cmd):
    print(" ".join(cmd))
    sp.check_call(cmd)


def run_tests(crc32c_sw_mode):
    os.environ["CRC32C_SW_MODE"] = crc32c_sw_mode
    os.environ["CRC32C_SKIP_HW_PROBE"] = ["0", "1"][crc32c_sw_mode == "none"]
    message = "# Tests for CRC32C_SW_MODE: %s #" % crc32c_sw_mode
    hashes = "#" * len(message)
    print("\n" + hashes)
    print(message)
    print(hashes + "\n")
    run([sys.executable, "-m", "pytest", "-v", os.path.join(SCRIPT_DIR, "test")])


def main():
    run_tests("auto")
    run_tests("force")
    run_tests("none")


if __name__ == "__main__":
    main()



import contextlib
from typing import Iterable, Tuple, no_type_check

import pytest

import crc32c

try:
    from test.support.interpreters import Interpreter  # type: ignore
    from test.support.interpreters import create, queues
except ImportError:
    pytest.skip("No sub-interpreter support", allow_module_level=True)


@pytest.fixture(name="interpreter")
def interpreter_fixture() -> Iterable[Interpreter]:
    interpreter = create()
    with contextlib.closing(interpreter):
        yield interpreter


def test_crc32c_can_be_loaded(interpreter: Interpreter) -> None:
    interpreter.exec("import crc32c")
    # all good, no exception raised


@pytest.mark.calculates_crc32c
def test_crc32c_can_run(interpreter: Interpreter) -> None:

    queue = queues.create()
    VALUE = b"test"
    interpreter.prepare_main(queue_id=queue.id, value_in=VALUE)

    @no_type_check
    def crc32c_in_subinterpreter() -> None:
        from test.support.interpreters.queues import Queue  # type: ignore

        import crc32c

        queue = Queue(queue_id)
        value_out = crc32c.crc32c(value_in)
        queue.put(value_out)

    thread = interpreter.call_in_thread(crc32c_in_subinterpreter)
    result = queue.get(timeout=5)
    thread.join()
    assert result == crc32c.crc32c(VALUE)



#
#    ICRAR - International Centre for Radio Astronomy Research
#    (c) UWA - The University of Western Australia, 2024
#    Copyright by UWA (in the framework of the ICRAR)
#    All rights reserved
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston,
#    MA 02111-1307  USA
#

import time

import pytest

import crc32c


def _crc32c_is_available() -> bool:
    try:
        crc32c.crc32c(b"dummy")
        return True
    except RuntimeError:
        return False


@pytest.fixture
def crc32c_is_available() -> bool:
    return _crc32c_is_available()


@pytest.fixture(autouse=True)
def skip_if_crc32c_unavailable(
    request: pytest.FixtureRequest, crc32c_is_available: bool
) -> None:
    if request.node.get_closest_marker("calculates_crc32c") and not crc32c_is_available:
        pytest.skip("crc32c is not available on this platform")


def pytest_sessionstart(session: pytest.Session) -> None:
    print("crc32c is big endian? ", crc32c.big_endian)
    print("crc32c is hardware based? ", crc32c.hardware_based)



#
#    ICRAR - International Centre for Radio Astronomy Research
#    (c) UWA - The University of Western Australia, 2014
#    Copyright by UWA (in the framework of the ICRAR)
#    All rights reserved
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston,
#    MA 02111-1307  USA
#
import glob

from setuptools import Extension, setup

crcmod_ext = Extension(
    "crc32c._crc32c",
    define_macros=[("NDEBUG", None)],
    depends=glob.glob("src/crc32c/ext/*.h"),
    language="c",
    sources=glob.glob("src/crc32c/ext/*.c"),
    include_dirs=["src/cc32c/ext/"],
)

classifiers = [
    # There's no more specific classifier for LGPLv2.1+
    "License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)",
    "Operating System :: OS Independent",
    "Programming Language :: C",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Programming Language :: Python :: 3.10",
    "Programming Language :: Python :: 3.11",
    "Programming Language :: Python :: 3.12",
    "Programming Language :: Python :: 3.13",
]

with open("README.rst", "rt") as f:
    long_description = f.read()

setup(
    name="crc32c",
    author="The ICRAR DIA Team",
    url="https://github.com/ICRAR/crc32c",
    author_email="rtobar@icrar.org",
    version="2.7.1",
    license="LGPL-2.1-or-later",
    description=(
        "A python package implementing the crc32c algorithm" " in hardware and software"
    ),
    long_description=long_description,
    long_description_content_type="text/x-rst",
    classifiers=classifiers,
    packages=["crc32c"],
    package_dir={"": "src"},
    package_data={"crc32c": ["*.pyi", "py.typed", "ext/*.h"]},
    python_requires=">=3.7",
    ext_modules=[crcmod_ext],
    test_suite="test",
)
